# This file is part of the Juju GUI, which lets users view and manage Juju
# environments within a graphical interface (https://launchpad.net/juju-gui).
# Copyright (C) 2013 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Affero General Public License version 3, as published by
# the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranties of MERCHANTABILITY,
# SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Juju Quickstart application management."""

from __future__ import print_function
import argparse
import os

import quickstart


default_envfile = os.path.expanduser('~/.juju/environments.yaml')
description = 'set up a Juju environment (including the GUI) in very few steps'
version = quickstart.get_version()


class _DescriptionAction(argparse.Action):
    """A customized argparse action that just shows a description."""

    def __call__(self, parser, *args, **kwargs):
        print(description)
        parser.exit()


def setup():
    """Set up the application options."""
    parser = argparse.ArgumentParser(description=quickstart.__doc__)
    parser.add_argument(
        '-e', '--environment', required=True, dest='env_name',
        help='the name of the Juju environment to use')
    parser.add_argument(
        '--environments-file', dest='env_file', type=file,
        default=default_envfile,
        help='the path to the Juju environments YAML file')
    parser.add_argument(
        '--version', action='version', version='%(prog)s {}'.format(version))
    # This is required by juju-core: see "juju help plugins".
    parser.add_argument(
        '--description', action=_DescriptionAction, default=argparse.SUPPRESS,
        nargs=0, help="show program's description and exit")
    return parser.parse_args()


def run(options):
    """Run the application"""
    print('juju quickstart v{}'.format(version))
    # TODO: everything!
